# pypi-mr
This package allows:
1. check if package exists on pypi registry using [simple API](https://warehouse.pypa.io/api-reference/legacy.html#simple-project-api).
2. clean packages that belongs to closed/merged GitLab MRs
